@@ -45,15 +45,16 @@ def make_private_flow(answers: dict):
     while "next" in response.links:
         url = response.links["next"]["url"]
 
-    response = requests.get(url, headers=headers)
-    data = response.json()
-    results.extend(data)
+        response = requests.get(url, headers=headers)
+        data = response.json()
+        results.extend(data)
 
-    with open("data_repos.json", "w") as outfile:
-        outfile.write(json.dumps(results))
 
     for repo in results:
         if repo.get("visibility") == "internal":
             repo_name = repo.get("name")
             print(f"{repo_name} is internal, making it private")
             make_private(repo_name=repo.get("name"), answers=answers)
+        else:
+            repo_name = repo.get("name")
+            print(f"{repo_name} is already private")
